@@ -8,7 +8,7 @@ from .entity import Entity
 from .zone import Zone
 from .token import Token
 from .api_handler import NotFoundError
-from .op_deployment import get_op_deployment
+from .op_deployment import OPDeployment
 
 
 class Account(Entity):
@@ -23,7 +23,11 @@ class Account(Entity):
 
     @property
     def url_base(self):
-        return "/accounts/{}".format(self._id)
+        return "/accounts"
+
+    @property
+    def url_id(self):
+        return '{}/{}'.format(self.url_base, self._id)
 
     @property
     def company(self):
@@ -203,18 +207,53 @@ class Account(Entity):
             return result
         else:
             return Zone(result['id'], result, api=self.api, **kwargs)
-
-    def get_op_deployment(self, op_deployment_id, params=None, raw=False, api_call_kwargs={}):
-        """:obj:`Zone`: Fetch the on prem deployment with specified id in the account.
+    
+    def get_op_deployments(self, params=None, raw=False, api_call_kwargs={}):
+        """:obj:`list` of :obj:`OpDeployment`: Fetch a list of all deployments in the account.
 
         Args:
-            op_deployment_id (str): on prem deployment ID.
             params (dict): Optional query parameters.
             raw (bool): Will return the raw JSON if True. False by default.
             api_call_kwargs (dict): Optional keyword arguments for api call.
+            **kwargs (dict): Extra attributes for Zone objects.
         """
-        return get_op_deployment(self.api, self._id, op_deployment_id, params=params, raw=raw,
-                                 api_call_kwargs=api_call_kwargs)
+        result = self.api.call(
+            "GET",
+            "accounts/{}/op-deployments".format(self._id),
+            params=params,
+            **api_call_kwargs,
+        )
+        if not result:
+            return []
+        if raw:
+            return result
+        else:
+            return [
+                OPDeployment(data['id'], data, api=self.api)
+                for data in result
+            ]
+
+    def get_op_deployment(self, op_deployment_id, params=None, raw=False, api_call_kwargs={}):
+        """:obj:`OPDeployment`: Fetch a deployment by its ID.
+
+        Args:
+            op_deployment_id (string): ID of the on prem deployment
+            params (dict): Optional query parameters.
+            raw (bool): Will return the raw JSON if True. True by default.
+            api_call_kwargs (dict): Optional keyword arguments for api call.
+        """
+        response = self.api.call(
+            "GET",
+            "accounts/{}/op-deployments/{}".format(self._id, op_deployment_id),
+            params=params,
+            **api_call_kwargs
+        )
+        if not response:
+            return None
+        elif raw:
+            return response
+        else:
+            return OPDeployment(response['id'], response, api=self.api)
 
     def get_alert(self, alert_id, attributes=None, raw=False, params=None, api_call_kwargs={}):
         """:obj:`Alert`: Fetch an Alert by its ID
